@@ -5,17 +5,6 @@ from ._version import get_versions
 __version__ = get_versions()["version"]
 del get_versions
 
-import matplotlib as mpl
-import matplotlib.pyplot as plt
-
-try:
-    mpl.use("QT5Agg")
-    plt.style.use("seaborn-paper")
-except:
-    pass
-del mpl
-del plt
-
 # add logger to console
 import logging
 
